==> scorchful-0.16.0%2B1.21.9-sources.jar: com/github/thedeathlycow/scorchful/entity/model/SunHatModel.java <==
package com.github.thedeathlycow.scorchful.entity.model;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_10034;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_572;
import net.minecraft.class_6230;
import net.minecraft.class_630;
import net.minecraft.class_9953;
import net.minecraft.client.model.*;

@Environment(EnvType.CLIENT)
public class SunHatModel<S extends class_10034> extends class_572<S> {
    public static final class_9953 BABY_TRANSFORMER = class_9953.scaling(0.5f);

    public SunHatModel(class_630 root) {
        super(root);
        this.method_2805(false);
        this.field_3398.field_3665 = true;
    }

    public static class_5607 getTexturedModelData() {
        class_5609 modelData = class_572.method_32011(class_5605.field_27715, 0.0f);
        class_5610 root = modelData.method_32111();
        root.method_32117(
                class_6230.field_32606,
                class_5606.method_32108()
                        .method_32101(0, 0)
                        .method_32098(
                                -8.0F, -4.5F, -8.0F,
                                16.0F, 0.0F, 16.0F,
                                class_5605.field_27715.method_32095(0.1f, 0f, 0.1f)
                        )
                        .method_32101(0, 16)
                        .method_32098(
                                -4.0F, -9.0F, -4.0F,
                                8.0F, 4.0F, 8.0F,
                                class_5605.field_27715.method_32094(0.6f)
                        ),
                class_5603.method_32090(0.0f, 0f, 0.0f)
        );

        return class_5607.method_32110(modelData, 64, 64);
    }

    public static class_5607 getBabyTexturedModelData() {
        return getTexturedModelData().method_62137(field_52918);
    }
}

==> scorchful-0.16.2%2B1.21.10-sources.jar: com/github/thedeathlycow/scorchful/entity/model/SunHatModel.java <==
package com.github.thedeathlycow.scorchful.entity.model;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_10034;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_572;
import net.minecraft.class_6230;
import net.minecraft.class_630;
import net.minecraft.class_9953;
import net.minecraft.client.model.*;

@Environment(EnvType.CLIENT)
public class SunHatModel<S extends class_10034> extends class_572<S> {
    public static final class_9953 field_52918 = class_9953.scaling(0.5f);

    public SunHatModel(class_630 root) {
        super(root);
        this.method_2805(false);
        this.field_3398.field_3665 = true;
    }

    public static class_5607 getTexturedModelData() {
        class_5609 modelData = class_572.method_32011(class_5605.field_27715, 0.0f);
        class_5610 root = modelData.method_32111();
        root.method_32117(
                class_6230.field_32606,
                class_5606.method_32108()
                        .method_32101(0, 0)
                        .method_32098(
                                -8.0F, -4.5F, -8.0F,
                                16.0F, 0.0F, 16.0F,
                                class_5605.field_27715.method_32095(0.1f, 0f, 0.1f)
                        )
                        .method_32101(0, 16)
                        .method_32098(
                                -4.0F, -9.0F, -4.0F,
                                8.0F, 4.0F, 8.0F,
                                class_5605.field_27715.method_32094(0.6f)
                        ),
                class_5603.method_32090(0.0f, 0f, 0.0f)
        );

        return class_5607.method_32110(modelData, 64, 64);
    }

    public static class_5607 getBabyTexturedModelData() {
        return getTexturedModelData().method_62137(field_52918);
    }
}
